@@ -41,7 +41,7 @@ ce[, nmb2 := qalys * kval2 - cost]
 
 # Functions to use for testing ------------------------------------------------
 # probabilistic sensitivity analysis
-iceaR <- function(x, kval, grpname){
+ceaR <- function(x, kval, grpname){
   x <- x[grp == grpname] 
   x[, nmb := qalys * kval - cost]
   nmb <- data.table::dcast(x, sample ~ strategy, value.var = "nmb")
@@ -96,15 +96,15 @@ ceacR <- function(ix, kval, grpname) {
   ceac <- ix[, .(prob = mean(nmb >= 0)), by = "strategy"]
 }
 
-# Test icea function ----------------------------------------------------------
-test_that("icea", {
+# Test cea function ------------------------------------------------------------
+test_that("cea", {
   
   # function gets expected results
-  icea <-  icea(ce, k = krange, sample = "sample", strategy = "strategy",
-                   grp = "grp", e = "qalys", c = "cost")
+  cea <-  cea(ce, k = krange, sample = "sample", strategy = "strategy",
+              grp = "grp", e = "qalys", c = "cost")
   kval <- sample(krange, 1)
-  iceaR_1 <- iceaR(ce, kval , "Group 1")
-  iceaR_2 <- iceaR(ce, kval , "Group 2")
+  ceaR_1 <- ceaR(ce, kval , "Group 1")
+  ceaR_2 <- ceaR(ce, kval , "Group 2")
   
   ## summary
   ### group 2
@@ -121,56 +121,56 @@ test_that("icea", {
                                         c_mean = ce_mean$c_mean, 
                                         c_lower = ce_lower$c_lower,
                                         c_upper = ce_upper$c_upper)
-  expect_equal(summary_test, icea$summary[grp == "Group 2", -2, with = FALSE])
+  expect_equal(summary_test, cea$summary[grp == "Group 2", -2, with = FALSE])
   
   # mce
   ### group 1
-  mce <- icea$mce[grp == "Group 1" &  k == kval]
-  mce_test <- iceaR_1$mce
+  mce <- cea$mce[grp == "Group 1" &  k == kval]
+  mce_test <- ceaR_1$mce
   expect_equal(mce$prob, mce_test)
   
   ### group 2
-  mce <- icea$mce[grp == "Group 2" &  k == kval]
-  mce_test <- iceaR_2$mce
+  mce <- cea$mce[grp == "Group 2" &  k == kval]
+  mce_test <- ceaR_2$mce
   expect_equal(mce$prob, mce_test)
   
   ## CEAF
   ### group 1
-  ceaf <- icea$mce[best == 1 & grp == "Group 1" &  k == kval]
-  ceaf_test <- iceaR_1$ceaf
+  ceaf <- cea$mce[best == 1 & grp == "Group 1" &  k == kval]
+  ceaf_test <- ceaR_1$ceaf
   expect_equal(ceaf$prob, ceaf_test)
   
   ### group 2
-  ceaf <- icea$mce[best == 1 & grp == "Group 2" &  k == kval]
-  ceaf_test <- iceaR_2$ceaf
+  ceaf <- cea$mce[best == 1 & grp == "Group 2" &  k == kval]
+  ceaf_test <- ceaR_2$ceaf
   expect_equal(ceaf$prob, ceaf_test)  
   
   ## evpi
   ### group 1
-  evpi <- icea$evpi[grp == "Group 1" &  k == kval]
-  evpi_test <- iceaR_1$evpi
+  evpi <- cea$evpi[grp == "Group 1" &  k == kval]
+  evpi_test <- ceaR_1$evpi
   expect_equal(evpi$evpi, evpi_test)
   
   ## function works with other names
   ce2 = data.table::copy(ce)
   data.table::setnames(ce2, c("sample", "strategy", "grp"), c("samp", "strategy_name", "group"))
-  icea2 <-  icea(ce2, k = krange, sample = "samp", strategy = "strategy_name",
-                   grp = "group", e = "qalys", c = "cost")
-  evpi_v2 <- icea2$evpi[group == "Group 1" &  k == kval]
+  cea2 <-  cea(ce2, k = krange, sample = "samp", strategy = "strategy_name",
+               grp = "group", e = "qalys", c = "cost")
+  evpi_v2 <- cea2$evpi[group == "Group 1" &  k == kval]
   expect_equal(evpi_v2$evpi, evpi$evpi)
 })
 
-# Test icea_pw function -------------------------------------------------------
-test_that("icea_pw", {
+# Test cea_pw function ---------------------------------------------------------
+test_that("cea_pw", {
   
   ### function gets expected results
-  icea_pw <-  icea_pw(ce, k = krange, comparator = "Strategy 1",
+  cea_pw <-  cea_pw(ce, k = krange, comparator = "Strategy 1",
                          sample = "sample", strategy = "strategy", grp = "grp",
                       e = "qalys", c = "cost")
   kval <- sample(krange, 1)
   
   ## delta
-  delta <- icea_pw$delta
+  delta <- cea_pw$delta
   delta_test <- deltaR(ce, comparator = "Strategy 1", grpname = "Group 1")
   expect_equal(delta[grp == "Group 1"], delta_test)
   
@@ -191,22 +191,22 @@ test_that("icea_pw", {
                                          ic_lower = delta_lower$ic_lower,
                                          ic_upper = delta_upper$ic_upper, 
                                          icer = icer)
-  expect_equal(summary_test, icea_pw$summary[grp == "Group 2", -2, with = FALSE])
+  expect_equal(summary_test, cea_pw$summary[grp == "Group 2", -2, with = FALSE])
   
   ## ceac
   # group 1
-  ceac <- icea_pw$ceac[grp == "Group 1" & k == kval]
+  ceac <- cea_pw$ceac[grp == "Group 1" & k == kval]
   ceac_test <- ceacR(delta, kval = kval, grpname = "Group 1")
   expect_equal(ceac$prob, ceac_test$prob)
   
   # group 2
-  ceac <- icea_pw$ceac[grp == "Group 2" & k == kval]
+  ceac <- cea_pw$ceac[grp == "Group 2" & k == kval]
   ceac_test <- ceacR(delta, kval = kval, grpname = "Group 2")
   expect_equal(ceac$prob, ceac_test$prob)
   
   ## inmb
   # group 2
-  inmb <- icea_pw$inmb[k == kval & grp == "Group 2"]
+  inmb <- cea_pw$inmb[k == kval & grp == "Group 2"]
   einmb_test <- delta[grp == "Group 2", .(einmb = mean(ie * kval - ic)), 
                      by = "strategy"]
   expect_equal(inmb$einmb, einmb_test$einmb)
@@ -214,35 +214,35 @@ test_that("icea_pw", {
   ### function works with other names
   ce2 = data.table::copy(ce)
   data.table::setnames(ce2, c("sample", "strategy", "grp"), c("samp", "strategy_name", "group"))
-  icea_pw2 <- icea_pw(ce2,  k = krange, comparator = "Strategy 1",
-                         sample = "samp", strategy = "strategy_name", grp = "group",
-                         e = "qalys", c = "cost")
-  ceac_v2 <- icea_pw2$ceac[group == "Group 2" & k == kval]
+  cea_pw2 <- cea_pw(ce2,  k = krange, comparator = "Strategy 1",
+                    sample = "samp", strategy = "strategy_name", grp = "group",
+                    e = "qalys", c = "cost")
+  ceac_v2 <- cea_pw2$ceac[group == "Group 2" & k == kval]
   expect_equal(ceac$prob, ceac_v2$prob)
   
   ## ICER table
-  icer <- icer_tbl(icea_pw)
+  icer <- icer_tbl(cea_pw)
   expect_true(inherits(icer, "list"))
   expect_true(inherits(icer[[1]], "matrix"))
   
-  icer <- icer_tbl(icea_pw, cri = FALSE)
+  icer <- icer_tbl(cea_pw, cri = FALSE)
   expect_true(inherits(icer, "list"))
   
-  icer <- icer_tbl(icea_pw, output = "data.table")
+  icer <- icer_tbl(cea_pw, output = "data.table")
   expect_true(inherits(icer, "data.table"))
   
-  icea_pw2 <-  icea_pw(ce[grp == "Group 1"],  k = krange, comparator = "Strategy 1",
-                         sample = "sample", strategy = "strategy", e = "qalys", c = "cost")
-  icer <- icer_tbl(icea_pw2)
+  cea_pw2 <-  cea_pw(ce[grp == "Group 1"],  k = krange, comparator = "Strategy 1",
+                     sample = "sample", strategy = "strategy", e = "qalys", c = "cost")
+  icer <- icer_tbl(cea_pw2)
   expect_true(inherits(icer, "matrix"))
   expect_equal(ncol(icer), 3)
   
-  icer <- icer_tbl(icea_pw2, drop = FALSE)
+  icer <- icer_tbl(cea_pw2, drop = FALSE)
   expect_true(inherits(icer, "list"))
   
   cols <- c("S1", "S2", "S3")
   rows <- c("iqalys", "icosts", "inmb", "icer", "conclusion")
-  icer <- icer_tbl(icea_pw2, 
+  icer <- icer_tbl(cea_pw2, 
                    colnames = cols,
                    rownames = rows)
   expect_true(inherits(icer, "matrix"))
@@ -251,14 +251,14 @@ test_that("icea_pw", {
   
   ### Strategy 2 is cost saving and better
   ce2[strategy_name == "Strategy 3", cost := 2]
-  icea_pw2 <- icea_pw(ce2,  k = krange, comparator = "Strategy 1",
-                      grp = "group",
-                      sample = "samp", strategy = "strategy_name", 
-                      e = "qalys", c = "cost")
+  cea_pw2 <- cea_pw(ce2,  k = krange, comparator = "Strategy 1",
+                    grp = "group",
+                    sample = "samp", strategy = "strategy_name", 
+                    e = "qalys", c = "cost")
   
   ### Errors
   expect_error(icer_tbl(2)) 
-  expect_error(icer_tbl(icea_pw, prob = 1.4)) 
+  expect_error(icer_tbl(cea_pw, prob = 1.4)) 
 })
 
 # Test incr_effect function ---------------------------------------------------
